@@ -19,7 +19,7 @@ after 'login' => sub {
 
 =head1 NAME
 
-CatalystX::SimpleLogin::TraitFor::Controller::Login::RenderAsTTTemplate
+CatalystX::SimpleLogin::TraitFor::Controller::Login::RenderAsTTTemplate - render a login form with no template file
 
 =head1 DESCRIPTION
 
